@@ -1,7 +1,7 @@
 from .export_data import export_users_to_csv, export_users_to_json_lines, export_tweets_to_csv, \
     export_tweets_to_json_lines
 from .get_user_runner import GetUsersTask, GetUsersRunner, GetUsersResult
-from .http_request.web_client import WebClient
+from .http_request import WebClient, RequestsWebClient, RequestsWebClientProxyConfig
 from .import_data import read_tweets_from_csv_file, read_tweets_from_json_lines_file, read_users_from_csv_file, \
     read_users_from_json_lines_file
 from .model import Language, Tweet, User
